#ifndef ATTRIBUTE_H
#define ATTRIBUTE_H

#include <QStringList>

#include "xmlobj.h"

class AttributeTable;

/*! \brief A key and a value
*/

class Attribute:public XMLObj {
public:
	Attribute();
	void setKey (const QString &k);
	QString getKey ();
	void setValue (const QString &v);
	QString getValue();
	void setTable (AttributeTable *at);
	AttributeTable* getTable();
	QString getDataXML();
protected:
	QString key;
	QString value;
	AttributeTable *table;
};

/*! \brief A table containing a list of keys and each of these keys has
   a list of default values. The keys and the values for each key are
   unique.
*/
class AttributeTable:public XMLObj{
public:
	AttributeTable();
	~AttributeTable();
	void clear();
	void addKey (const QString &k);		//!< Adds a key to the table
	void removeKey (const QString &k);	//!< Removes key and its default values
	int countKeys();					//!< Return number of keys
	void addValue (const QString &k, const QString &v);	//!< Adds key and value
	QStringList getKeys ();
	QStringList getValues(const QString &k);
	QString getDataXML();

protected:
	QStringList keys;
	QList <QStringList> values;
};



#endif

